==> phplist-2.10.5p0.tgz: lists/admin/lan/de/users.php <==
<?php

$lan = array(
'Delete will delete user and all listmemberships'
	=> 'Wenn Sie einen Abonnenten l&ouml;schen, werden sowohl der Abonnent selbst als auch alle seine Listen-Abonnemente gel&ouml;scht.',
'%s users apply' => '%s Abonnent(en) gefunden',
'Users marked <font color=red>red</font> are unconfirmed'
	=> 'Abonnenten in <font color=red>rot</font> sind nicht best&auml;tigt',
'Show only unconfirmed users' => 'Nur unbest&auml;tigte Abonnenten',
'Show only blacklisted users' => 'Nur Abonnenten auf Blacklist',
'email' => 'E-Mail-Adresse',
'bouncecount' => 'Anzahl Retouren',
'entered' => 'Erfassungsdatum',
'modified' => '&Auml;nderungsdatum',
'foreignkey' => 'Fremdschl&uuml;ssel',
'Sort by' => 'Sortierung',
'desc' => 'absteigend',
'asc' => 'aufsteigend',
'Go' => 'Anzeigen',
'Find a user' => 'Abonnenten suchen',
'Email' => 'E-Mail-Adresse',
'Foreign Key' => 'Fremdschl&uuml;ssel',
'reset' => 'Zur&uuml;cksetzen',
'Download all users as CSV file'
	=> 'Abonnenten exportieren',
'Add a User' => 'Neuer Abonnent',
'confirmed' => 'Best&auml;tigt',
'bl l' => 'Blacklist', # as in black listed (but then as short as possible)
'del' => 'L&ouml;schen',
'key' => 'Schl&uuml;ssel',
'msgs' => 'Nachr.', # meaning messages
'rss' => 'RSS',
'rss freq' => 'RSS-H&auml;ufigkeit', # meaning rss frequency
'bncs' => 'Retouren', # meaning bounces
'No users apply' => 'Keine Abonnenten gefunden',
'Your privileges for this page are insufficient'
	=> 'Sie haben keine Zugriffsberechtigung f&uuml;r diese Seite.',
'Delete will delete user from the list'
	=> 'L&ouml;sch-Befehl l&ouml;scht den Abonnenten von der Liste',
'deleting' => 'L&ouml;sche',
'Done' => 'Abgeschlossen',
'User added' => 'Abonnent hinzugef&uuml;gt',
'Add this user' => 'Abonnent hinzuf&uuml;gen',
'Click on a link to use the corresponding public subscribe page to add this user:'
	=> 'Klicken Sie auf einen Link, um die entsprechende &ouml;ffentliche Anmeldeseite aufzurufen und diesen Abonnenten hinzuzuf&uuml;gen:',
'Click this link to use the public subscribe page to add this user:'
	=> 'Klicken Sie auf diesen Link, um die entsprechende &ouml;ffentliche Anmeldeseite aufzurufen und diesen Abonnenten hinzuzuf&uuml;gen:',
'Listing user %d to %d' => 'Abonnenten %d bis %d',
'last sent' => 'Zuletzt gesendet',
);

?>

==> phplist-2.10.17p2.tgz: lists/admin/lan/de/users.php <==
<?php

$lan = array(
'Delete will delete user and all listmemberships'
	=> 'Wenn Sie einen Abonnenten l&ouml;schen, werden sowohl der Abonnent selbst als auch alle seine Listen-Abonnemente gel&ouml;scht.',
'%s users apply' => '%s Abonnent(en) gefunden',
'Users marked <span class="highlight">red</span> are unconfirmed'
	=> 'Abonnenten in <span class="highlight">rot</span> sind nicht best&auml;tigt',
'Show only unconfirmed users' => 'Nur unbest&auml;tigte Abonnenten',
'Show only blacklisted users' => 'Nur Abonnenten auf Blacklist',
'email' => 'E-Mail-Adresse',
'bouncecount' => 'Anzahl Retouren',
'entered' => 'Erfassungsdatum',
'modified' => '&Auml;nderungsdatum',
'foreignkey' => 'Fremdschl&uuml;ssel',
'Sort by' => 'Sortierung',
'desc' => 'absteigend',
'asc' => 'aufsteigend',
'Go' => 'Anzeigen',
'Find a user' => 'Abonnenten suchen',
'Email' => 'E-Mail-Adresse',
'Foreign Key' => 'Fremdschl&uuml;ssel',
'reset' => 'Zur&uuml;cksetzen',
'Download all users as CSV file'
	=> 'Abonnenten exportieren',
'Add a User' => 'Neuer Abonnent',
'confirmed' => 'Best&auml;tigt',
'bl l' => 'Blacklist', # as in black listed (but then as short as possible)
'del' => 'L&ouml;schen',
'key' => 'Schl&uuml;ssel',
'msgs' => 'Nachr.', # meaning messages
'rss' => 'RSS',
'rss freq' => 'RSS-H&auml;ufigkeit', # meaning rss frequency
'bncs' => 'Retouren', # meaning bounces
'No users apply' => 'Keine Abonnenten gefunden',
'Your privileges for this page are insufficient'
	=> 'Sie haben keine Zugriffsberechtigung f&uuml;r diese Seite.',
'Delete will delete user from the list'
	=> 'L&ouml;sch-Befehl l&ouml;scht den Abonnenten von der Liste',
'deleting' => 'L&ouml;sche',
'Done' => 'Abgeschlossen',
'User added' => 'Abonnent hinzugef&uuml;gt',
'Add this user' => 'Abonnent hinzuf&uuml;gen',
'Click on a link to use the corresponding public subscribe page to add this user:'
	=> 'Klicken Sie auf einen Link, um die entsprechende &ouml;ffentliche Anmeldeseite aufzurufen und diesen Abonnenten hinzuzuf&uuml;gen:',
'Click this link to use the public subscribe page to add this user:'
	=> 'Klicken Sie auf diesen Link, um die entsprechende &ouml;ffentliche Anmeldeseite aufzurufen und diesen Abonnenten hinzuzuf&uuml;gen:',
'Listing user %d to %d' => 'Abonnenten %d bis %d',
'last sent' => 'Zuletzt gesendet',
);

?>
